#
# spec file for package python-nautilus
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define oldpython python
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define _name nautilus-python
%define skip_python2 1

Name:           python-nautilus
Version:        4.0.1
Release:        1.4
Summary:        Python bindings for Nautilus
License:        GPL-2.0-or-later
Group:          Development/Libraries/Python
URL:            https://wiki.gnome.org/Projects/NautilusPython
Source:         https://download.gnome.org/sources/nautilus-python/4.0/%{_name}-%{version}.tar.xz
# PATCH-FIX-OPENSUSE: fix-hwcaps.patch -- bsc#1212474
Patch1:         fix-hwcaps.patch

BuildRequires:  %{python_module devel}
BuildRequires:  gtk-doc
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libnautilus-extension-4) >= 43.beta
BuildRequires:  pkgconfig(pygobject-3.0) >= 3.0.0

Requires:       %{name}-common-files = %{version}
Requires:       python-gobject
# we can't have automatic typelib() Requires here: it's C code: PyImport_ImportModule("gi.repository.Nautilus")
Requires:       typelib(Nautilus)
%python_subpackages

%description
This package contains bindings to write Nautilus extensions with Python.
It allows writing menu, property pages and column providers extensions,
so that Nautilus functionality can be easily extended.

%package -n %{name}-common-files
Summary:        Python nautilus files shared between python interpreter versions
Group:          Development/Libraries/Python
Provides:       %{python_module nautilus-common-files = %{version}}

%description -n %{name}-common-files
This package contains common files required to build wrappers for
python-nautilus in both Python2 and Python3.

%package devel
Summary:        Metapackage to pull in all of python-nautilus' packages
Group:          Development/Libraries/Python
Requires:       %{name} >= %{version}
Requires:       %{name}-common-devel = %{version}
Requires:       python-devel

%description devel
This package contains files required to build wrappers for python-nautilus.

%package -n %{name}-common-devel
Summary:        Shared development files for python-nautilus
Group:          Development/Libraries/Python
Requires:       python3-nautilus-devel = %{version}
Provides:       %{python_module nautilus-common-devel = %{version}}

%description -n %{name}-common-devel
This package contains common files required to build wrappers for
python-nautilus in both Python2 and Python3.

%prep
%autosetup -p1 -n %{_name}-%{version}

%build
%{python_expand export PYTHON=$python
%define _vpath_builddir build_%{$python_bin_suffix}
sed -i "s|docdir =.*|docdir = '%{_docdir}/$python-nautilus'|g" meson.build
%meson
%meson_build
}

%install
%{python_expand export PYTHON=$python
%define _vpath_builddir build_%{$python_bin_suffix}
sed -i "s|docdir =.*|docdir = '%{_docdir}/$python-nautilus'|g" meson.build
%meson_install
}

# New dir where python extensions get installed. It's not created by make
# install (bgo#638890).
test ! -d %{buildroot}%{_datadir}/nautilus-python/extensions
find %{buildroot} -type f -name "*.la" -delete -print
find %{buildroot} -size 0 -delete
mkdir -p %{buildroot}%{_datadir}/nautilus-python/extensions

%files %{python_files}
%license COPYING
%doc %{_docdir}/%{python_flavor}-nautilus/

%files -n %{name}-common-files
%doc NEWS.md
%{_libdir}/nautilus/extensions-4/libnautilus-python.so
%dir %{_datadir}/nautilus-python
%dir %{_datadir}/nautilus-python/extensions

%files %{python_files devel}
%doc AUTHORS

%files -n %{name}-common-devel
%doc %{_datadir}/gtk-doc/html/nautilus-python
%{_datadir}/pkgconfig/nautilus-python.pc

%changelog
* Fri Apr 19 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.0.1:
  + Fixed build failure due to underlinking.
  + Fixed build failure with Python 3.13.
* Mon Jul  3 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add fix-hwcaps.patch to fix the issue with Nautilus: Segmentation
  fault (core dumped) with libpython3_11-1_0-x86-64-v3
  (bsc#1212474)
* Sun Sep 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.0:
  + Updated migration docs and rewrote overview.
* Tue Aug 16 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.0.alpha:
  + The extension was ported to Nautilus 43: Notably, this removes
    any direct access to GTK widgets from the API. Most scripts
    will need to be modified. Please check the migration guide in
    the docs on how to update your scripts.
  + Switched to Meson build system.
  + Removed support for Python 2.
  + Fixed build with -fno-common.
  + Added missing parent constructor calls to examples.
  + Decorated the examples with typehints.
  + Fixed several memory leaks.
- Drop python-nautilus-gcc10-buildfix.patch: fixed upstream.
- Add meson BuildRequires and replace configur/make/make_install
  macros with relevant meon/meson_build/meson_install variants.
* Thu Jun  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Add python-nautilus-gcc10-buildfix.patch: Fix build with gcc 10.
* Wed Dec  4 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Fix Requires in devel subpackage, needed now we only build
  python3 variant.
* Wed Nov 20 2019 Dominique Leuenberger <dimstar@opensuse.org>
- No longer build python2 variant: This did not really work anyway
  as python-nautilus-commonp_files was not that common between py2
  and py3: the .so file actually linked one of the python
  interpreters directly (boo#1157305).
* Thu Jul 18 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.2.3:
  + Fixed open-terminal example extension.
  + Fixed glgo#GNOME/nautilus-python#3: setting argv[0] to thunar.
  + Fixed glgo#GNOME/nautilus-python#4: allow overriding the build
    date to enable reproducible builds.
  + Removed build warnings.
  + Fix to work with python 3.8.
- Drop reproducible.patch: Fixed upstream.
- Use modern macros.
* Fri Jul 12 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to override build date (boo#1047218)
* Mon May  7 2018 luc14n0@linuxmail.org
- Update to version 1.2.2:
  + Fix folder string comparison to prevent duplicate extension
    loading (bgo##792427).
* Mon Jan  8 2018 luc14n0@linuxmail.org
- Update to version 1.2.1:
  + Fix syntax error when building docs using python3 (bgo#792348).
- Changes from version 1.2:
  + Added capability to compile with python 3 support using PYTHON
    environment variable.
  + Improve extension path loading semantics to follow XDG
    recommendations (bgo#781232).
  + Require Nautilus 3.0 before importing extensions to prevent
    warnings (bgo#791208).
- Turn the package into singlespec.
- Update URL tag to https://wiki.gnome.org/Projects/NautilusPython:
  currently the Nautilus Python project's web page.
- Drop:
  + libtool BuildRequires and autoreconf call: the last is no
    longer needed and the former is automatically being pulled.
  + Standard BuilRoot setting tag: RPM already handles this itself.
- Pass --docdir=%%{_docdir}/%%{name} to configure for the use of the
  right documentation's directory.
- Unconditionalize gtk-doc BuildRequires as the documentation is
  building without further problems again.
- Remove unneeded %%clean section once RPM does this work itself
  nowadays.
- Correct out of order sentence in package descriptions.
* Wed May  9 2012 vuntz@opensuse.org
- Explicitly add missing typelib(Nautilus) Requires: we can't use
  the automatic typelib() Requires generator since this python
  module is written in C.
* Fri Dec  2 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Mon Oct 17 2011 dimstar@opensuse.org
- Update to version 1.1:
  + Added pygobject3 compatibility, and retained pygobject 2.28.x
    compatibility.
  + Bugs fixed: bgo#660290, bgo#660288, bgo#660287, bgo#660286,
    bgo#660283, bgo#653169.
- Drop patches that have been merged upstream:
  + python-nautilus-fix-path-in-pc.patch
  + python-nautilus-fix-warnings.patch
  + python-nautilus-no-extension-on-failure.patch
  + python-nautilus-pygobject-3.0.patch
* Wed Sep 28 2011 vuntz@opensuse.org
- Port to pygobject 3.0:
  + Add nautilus-python-pygobject-3.0.patch: do the port :-)
  + Change pkgconfig(pygobject-2.0) BuildRequires to
    pkgconfig(pygobject-3.0).
  + Add call to autoreconf, needed for the patch.
- Use a build_doc macro to decide whether to build the
  documentation. It controls the following:
  + Use of gtk-doc BuildRequires.
  + Use of --disable-gtk-doc or --enable-gtk-doc option passed to
    configure.
- Set build_doc macro to 0 as the documentation build currently
  requires the old pygobject.
- Add python-nautilus-fix-warnings.patch: fix various warnings in
  the build.
- Add python-nautilus-no-extension-on-failure.patch: do not load
  extensions on initialization failures.
* Wed Jun 22 2011 malcolmlewis@opensuse.org
- Fix /usr/share/nautilus-python directories not owned by a
  package.
- Update spec file Licence field from GPLv2+ to GPL-2.0+ to
  conform with spdx.org identifier.
* Fri Jun 17 2011 vuntz@opensuse.org
- Add python-nautilus-fix-path-in-pc.patch to fix the pkg-config
  file to refer to the right extension directory, now that it
  changed.
* Fri May 27 2011 vuntz@opensuse.org
- Update dependencies after move to gobject introspection:
  + Remove python-gnome-devel, python-gtk-devel BuildRequires,
    python-gtk Requires from main package, and python-gtk-devel
    Requires from devel subpackage.
  + Add pkgconfig(pygobject-2.0) BuildRequires and python-gobject
    Requires.
- Change nautilus-devel BuildRequires to
  pkgconfig(libnautilus-extension).
- Drop unneeded python-gobject2-doc BuildRequires.
- Fix license tag: the code is GPLv2+ (and not LGPLv2+).
- Stop creating %%{_libdir}/nautilus/extensions-2.0/python directory
  as extensions there are not considered anymore.
* Sun May 22 2011 dimstar@opensuse.org
- Update to version 1.0:
  + Use the gobject instrospection dynamic bindings, breaks
    compatibility for existing extensions.
  + For Nautilus3, the get_toolbar_items methods have been removed.
  + No longer look in the old ~/.nautilus/python-extensions or
    /usr/lib/nautilus/extensions2.0/python folders for extensions.
    Now look in ~/.local/share/nautilus-python/extensions or
    $XDG_DATA_DIR/nautilus-python/extensions.
  + Updated the gtk-doc documentation and examples to work with new
    dynamic bindings.
* Mon May  2 2011 dimstar@opensuse.org
- Update to version 0.7.3:
  + Use PyCapsule_Import for pygobject as well as pygtk
  + bgo#644399: in the property page example plugin, get the md5sum
    of the file contents, not the file name
  + Removed extraneous .cvsignore files
  + Fixed the update-file-info-async example plugin.
* Mon Mar 21 2011 dimstar@opensuse.org
- Update to version 0.7.2:
  + Fix to get the PyCapsule patch to work even if there is no
    PyCapsule object set up for pygtk
- Changes from version 0.7.1:
  + bgo#619440: Fixed AM_CHECK_PYTHON_LIBS usage of test
  + Cleaned up the docs Makefile.am to make it more consistent
  + Fix some python3 syntax issues in the python.m4 script
  + bgo#633171: Add python 2.7 support.
* Fri Jan  7 2011 vuntz@opensuse.org
- Create and own %%{_datadir}/nautilus-python/extensions since
  extensions can be installed there now.
* Sun Aug  8 2010 vuntz@opensuse.org
- Pass --enable-gtk-doc to configure, and add gtk-doc and
  python-gobject2-doc BuildRequires to build the API docs.
* Mon Jun 21 2010 dimstar@opensuse.org
- Update to version 0.7.0:
  + Added methods:
  - nautilus.InfoProvider.update_file_info_full
  - nautilus.InfoProvider.update_complete_invoke
  - nautilus.InfoProvider.cancel_update
  - nautilus.MenuProvider.get_file_items_full
  - nautilus.MenuProvider.get_background_items_full
  - nautilus.MenuProvider.get_toolbar_items_full
  - nautilus.MenuProvider.emit_items_updated_signal
  + Added complete gtk-doc documentation: tutorial and reference.
    Enable by adding the --enable-gtk-doc argument to ./configure
    or ./autogen.sh
  + Updated the autogen.sh file so it is not a copied-over obsolete
    version of gnome-autogen.sh, but a shell that calls the user's
    installed gnome-autogen.sh.
  + Removed obsolete .spec file
  + Removed obsolete examples/documentation.py file
  + Added an example plugin for the LocationWidgetProvider
  + Look for python plugins in
    $XDG_DATA_DIR/nautilus-python/extensions.
    This includes ~/.local/share and /usr/share (or whatever
    $XDG_DATA_DIR is set to).
* Tue Jan 19 2010 vuntz@opensuse.org
- Update to version 0.6.1:
  + Look for libpython2.6.so.1.0 instead of libpython2.6.so, the
    latter is general available from -devel packages only.
  + Re-added the missing spec and pc files
  + Free pygobject data directly after using file objects. Stops
    seg faults from occurring when nautilus wants to free pygobject
    data after Py_Finalize() is called.
* Fri Jan 15 2010 vuntz@opensuse.org
- Update to version 0.6.0:
  + Remove eel dependency
  + Sanitize python search path
  + Remove gnomevfs dependency and unused code
  + Load python from lib64 in 64 bit multilib distributions
  + Fix segfault when a plugin doesn't implement the __init__
    method
  + Added the can_write, get_mount, get_file_type, get_location,
    and get_parent_location methods to the NautilusFileInfo object
  + Added the NautilusMenu.get_items method
  + Updated some example plugins
  + Bug fix for some PyThreadState_New segmentation faults
  + Use the nautilus prefix by default for distfiles, rather than
    /usr
  + Require nautilus-2.22 and pygobject-2.16 now that we support
    GIO
- Drop python-nautilus-no-libeel.patch: fixed upstream.
- Drop python-nautilus-no-gnomevfs.patch: fixed upstream.
- Drop python-nautilus-autoreconf-m4.patch: not needed anymore,
  since we can remove the autoreconf call now.
* Sun Jun 14 2009 vuntz@novell.com
- Clean up package for Contrib.
